# l10n documentation

+ [README](../README.md) should get you up to speed on what is l10n and why it is cool.
+ [Getting Started](./intro.md) walks you through the process of creating and translating your first Python project.
+ [Advanced usage](./advanced.md) goes deeper into details and going beyond translating simple messages.
+ [Beyond l10n](./more.md) links some helpful tools and resources to find your way around of translating things.
+ [What we stripped away](./removed.md) tells the secret of l10n's simplicity.
